Documentation
¶
Index ¶
- Variables
- func GetExtraCommand(name string) func(args []string) error
- func PackageFiles(potatoYamlFile string, outputZipFile string) (string, error)
- func PushPackage(potatoYamlFile string, outputZipFile string) error
- func RegisterExtraCommand(name string, runner func(args []string) error)
- func Run()
- func RunBuildCommand(potatoYamlFile string) error
- func RunServerStartCommand(config string, autoSeed bool) error
- type CLI
- type DevCmd
- type DevPushCmd
- type DevRunStatelessCmd
- type ExtraCmd
- type OperationsBackupCmd
- type OperationsCmd
- type OperationsRestoreCmd
- type PackageBuildCmd
- type PackageCmd
- type PackageInitCmd
- type PackagePushCmd
- type ServerActualStartCmd
- type ServerCmd
- type ServerInitCmd
- type ServerStartCmd
- type ServerStopCmd
- type SingletonCmd
- type SingletonStartCmd
- type SkillsCmd
- type SkillsExportCmd
- type SkillsListCmd
- type SkillsShowCmd
- type TemplateInfo
Constants ¶
This section is empty.
Variables ¶
var TEMPLATES = []TemplateInfo{
{
Name: "React Lua",
RepoUrl: "https://github.com/blue-monads/potato-app-react-lua-template",
Slug: "potato-app-react-lua-template",
},
{
Name: "Vanilla Lua",
RepoUrl: "https://github.com/blue-monads/potato-app-vannilla-lua-template",
Slug: "potato-app-vannilla-lua-template",
},
}
Functions ¶
func GetExtraCommand ¶
func PushPackage ¶
func RegisterExtraCommand ¶
func RunBuildCommand ¶
func RunServerStartCommand ¶
Types ¶
type CLI ¶
type CLI struct {
Server ServerCmd `cmd:"" help:"Server management commands."`
Package PackageCmd `cmd:"" help:"Package management commands."`
Operations OperationsCmd `cmd:"" help:"Backup and restore operations."`
Dev DevCmd `cmd:"" help:"Development utilities."`
Extra ExtraCmd `cmd:"" help:"Extra commands."`
Skills SkillsCmd `cmd:"" help:"Skills management commands."`
Verbose bool `name:"verbose" short:"v" help:"Enable verbose output."`
}
type DevCmd ¶
type DevCmd struct {
Push DevPushCmd `cmd:"" help:"Push development changes."`
}
type DevPushCmd ¶
type DevPushCmd struct {
Target string `arg:"" help:"Push target."`
}
type DevRunStatelessCmd ¶
type ExtraCmd ¶
type OperationsBackupCmd ¶
type OperationsBackupCmd struct {
Output string `name:"output" short:"o" help:"Backup output path." type:"path"`
}
type OperationsCmd ¶
type OperationsCmd struct {
Backup OperationsBackupCmd `cmd:"" help:"Backup the database and files."`
Restore OperationsRestoreCmd `cmd:"" help:"Restore from a backup."`
}
type OperationsRestoreCmd ¶
type PackageBuildCmd ¶
type PackageCmd ¶
type PackageCmd struct {
Init PackageInitCmd `cmd:"" help:"Initialize a new project from a template."`
Build PackageBuildCmd `cmd:"" help:"Build the package."`
Push PackagePushCmd `cmd:"" help:"Push the package."`
}
type PackageInitCmd ¶
type PackageInitCmd struct {
Template string `name:"template" help:"Template slug or name to use. If omitted, choose interactively."`
Slug string `name:"slug" help:"Project slug (letters, digits and hyphens only). If omitted, prompt interactively."`
Directory string `name:"directory" short:"d" help:"Destination directory for new project." type:"path" default:"."`
}
type PackagePushCmd ¶
type ServerActualStartCmd ¶
type ServerCmd ¶
type ServerCmd struct {
InitAndStart ServerInitCmd `cmd:"" help:"Initialize the server with default options and start the server."`
Init ServerInitCmd `cmd:"" help:"Initialize the server with default options."`
Start ServerStartCmd `cmd:"" help:"Start the server."`
Stop ServerStopCmd `cmd:"" help:"Stop the server."`
ActualStart ServerActualStartCmd `cmd:"" help:"Actual start the server, called internally by the server start command."`
}
type ServerInitCmd ¶
type ServerInitCmd struct {
DBFile string `name:"db" help:"Path to database file." default:"data.db"`
Port int `name:"port" short:"p" help:"Server port." default:"7777"`
Host string `name:"host" help:"Server host." default:"*.localhost"`
Name string `name:"name" help:"Name of node." default:"PotatoVerse"`
SocketFile string `name:"socket-file" help:"Socket file of node."`
MasterSecret string `name:"master-secret" help:"Master secret of node."`
MasterSecretEnv string `name:"master-secret-env" help:"Master secret environment variable of node."`
Debug bool `name:"debug" help:"Debug mode of node." default:"false"`
WorkingDir string `name:"working-dir" help:"Working dir of node."`
Force bool `name:"force" short:"f" help:"Force initialization even if server is already initialized."`
}
type ServerStartCmd ¶
type ServerStopCmd ¶
type ServerStopCmd struct {
Force bool `name:"force" short:"f" help:"Force stop the server."`
}
type SingletonCmd ¶
type SingletonCmd struct {
Start SingletonStartCmd `cmd:"" help:"Start the singleton."`
}
type SingletonStartCmd ¶
type SkillsCmd ¶
type SkillsCmd struct {
List SkillsListCmd `cmd:"" help:"List available skills."`
Show SkillsShowCmd `cmd:"" help:"Show skill file content."`
Export SkillsExportCmd `cmd:"" help:"Export all skills to local directory."`
}
type SkillsExportCmd ¶
type SkillsExportCmd struct {
Dest string `arg:"" help:"Destination directory." default:"."`
}
func (*SkillsExportCmd) Run ¶
func (c *SkillsExportCmd) Run() error
type SkillsListCmd ¶
type SkillsListCmd struct{}
func (*SkillsListCmd) Run ¶
func (c *SkillsListCmd) Run() error
type SkillsShowCmd ¶
type SkillsShowCmd struct {
Path string `arg:"" help:"Path to the file to show (relative to skills root)."`
}
func (*SkillsShowCmd) Run ¶
func (c *SkillsShowCmd) Run() error
type TemplateInfo ¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.